<?php

/* 
 * Copied from AdminThemesController to support old versions 
 * and to avoid install/uninstall modules on farm for each theme
 */
class ThemeInstallHelper
{
    const UPLOADED_THEME_DIR_NAME = 'uploaded';
    private $errors = array();

    public function install($theme_zip_file, $sandbox, $redirect = false)
    {
        if ($this->extractTheme($theme_zip_file, $sandbox))
            if ($theme_directory = $this->installTheme(self::UPLOADED_THEME_DIR_NAME, $sandbox, $redirect)) {
                FilesHelper::removeDir($sandbox); // To catch permission exceptions
                //Tools::deleteDirectory($sandbox);
                return true;
            }

        return false;
    }

    public function getErrors()
    {
        return $this->errors;
    }

    protected function extractTheme($theme_zip_file, $sandbox)
    {
        if (Tools::ZipExtract($theme_zip_file, $sandbox.self::UPLOADED_THEME_DIR_NAME.'/'))
            return true;

        $this->errors[] = $this->l('Error during zip extraction');
        return false;
    }
    
    protected function installTheme($theme_dir, $sandbox = false, $redirect = true)
    {
        if (!$sandbox)
        {
            $uniqid = uniqid();
            $sandbox = _PS_CACHE_DIR_.'sandbox'.DIRECTORY_SEPARATOR.$uniqid.DIRECTORY_SEPARATOR;
            mkdir($sandbox);
            Tools::recurseCopy(_PS_ALL_THEMES_DIR_.$theme_dir, $sandbox.$theme_dir);
        }

        $xml_file = $sandbox.$theme_dir.'/Config.xml';
        if (!$this->checkXmlFields($xml_file))
            $this->errors[] = $this->l('Bad configuration file');
        else
        {
            $imported_theme = $this->importThemeXmlConfig(simplexml_load_file($xml_file));
            foreach ($imported_theme as $theme)
            {
                if (Validate::isLoadedObject($theme))
                {
                    if (!copy($sandbox.$theme_dir.'/Config.xml', _PS_ROOT_DIR_.'/config/xml/themes/'.$theme->directory.'.xml'))
                        $this->errors[] = $this->l('Can\'t copy configuration file');

                    $target_dir = _PS_ALL_THEMES_DIR_.$theme->directory;
                    if (file_exists($target_dir))
                        Tools::deleteDirectory($target_dir);

                    $theme_doc_dir = $target_dir.'/docs/';
                    if (file_exists($theme_doc_dir))
                        Tools::deleteDirectory($theme_doc_dir);

                    mkdir($target_dir);
                    mkdir($theme_doc_dir);

                    Tools::recurseCopy($sandbox.$theme_dir.'/themes/'.$theme->directory.'/', $target_dir.'/');
                    Tools::recurseCopy($sandbox.$theme_dir.'/doc/', $theme_doc_dir);
                    Tools::recurseCopy($sandbox.$theme_dir.'/modules/', _PS_MODULE_DIR_);
                }
                else
                    $this->errors[] = $theme;
            }
        }

        if (!count($this->errors))
        {
            if ($redirect)
                Tools::redirectAdmin(Context::getContext()->link->getAdminLink('AdminThemes').'&conf=18');
            else
                return true;
        }
        else
            return false;
    }
    
    private function checkXmlFields($xml_file)
    {
        if (!file_exists($xml_file) || !$xml = simplexml_load_file($xml_file))
            return false;
        if (!$xml['version'] || !$xml['name'])
            return false;
        foreach ($xml->variations->variation as $val)
        {
            if (!$val['name'] || !$val['directory'] || !$val['from'] || !$val['to'])
                return false;
        }
        foreach ($xml->modules->module as $val)
        {
            if (!$val['action'] || !$val['name'])
                return false;
        }
        foreach ($xml->modules->hooks->hook as $val)
        {
            if (!$val['module'] || !$val['hook'] || !$val['position'])
                return false;
        }

        return true;
    }
    
    protected function importThemeXmlConfig(SimpleXMLElement $xml, $theme_dir = false)
    {
        $attr = $xml->attributes();
        $th_name = (string)$attr->name;
        if ($this->isThemeInstalled($th_name))
            return array(sprintf($this->l('Theme %s already installed.'), $th_name));

        $new_theme_array = array();
        foreach ($xml->variations->variation as $variation)
        {
            $name = strval($variation['name']);

            $new_theme = new Theme();
            $new_theme->name = $name;

            $new_theme->directory = strval($variation['directory']);

            if ($theme_dir)
            {
                $new_theme->name = $theme_dir;
                $new_theme->directory = $theme_dir;
            }

            if ($this->isThemeInstalled($new_theme->name))
                continue;

            $new_theme->product_per_page = Configuration::get('PS_PRODUCTS_PER_PAGE');

            if (isset($variation['product_per_page']))
                $new_theme->product_per_page = intval($variation['product_per_page']);

            $new_theme->responsive = false;
            if (isset($variation['responsive']))
                $new_theme->responsive = (bool)strval($variation['responsive']);

            $new_theme->default_left_column = true;
            $new_theme->default_right_column = true;

            if (isset($variation['default_left_column']))
                $new_theme->default_left_column = (bool)strval($variation['default_left_column']);

            if (isset($variation['default_right_column']))
                $new_theme->default_right_column = (bool)strval($variation['default_right_column']);

            $fill_default_meta = true;
            $metas_xml = array();
            if ($xml->metas->meta)
            {
                foreach ($xml->metas->meta as $meta)
                {
                    $meta_id = Db::getInstance()->getValue('SELECT id_meta FROM '._DB_PREFIX_.'meta WHERE page=\''.pSQL($meta['meta_page']).'\'');
                    if ((int)$meta_id > 0)
                    {
                        $tmp_meta = array();
                        $tmp_meta['id_meta'] = (int)$meta_id;
                        $tmp_meta['left'] = intval($meta['left']);
                        $tmp_meta['right'] = intval($meta['right']);
                        $metas_xml[(int)$meta_id] = $tmp_meta;
                    }
                }
                $fill_default_meta = false;
                if (count($xml->metas->meta) < (int)Db::getInstance()->getValue('SELECT count(*) FROM '._DB_PREFIX_.'meta'))
                    $fill_default_meta = true;

            }

            if ($fill_default_meta == true)
            {
                $metas = Db::getInstance()->executeS('SELECT id_meta FROM '._DB_PREFIX_.'meta');
                foreach ($metas as $meta)
                {
                    if (!isset($metas_xml[(int)$meta['id_meta']]))
                    {
                        $tmp_meta['id_meta'] = (int)$meta['id_meta'];
                        $tmp_meta['left'] = $new_theme->default_left_column;
                        $tmp_meta['right'] = $new_theme->default_right_column;
                        $metas_xml[(int)$meta['id_meta']] = $tmp_meta;
                    }
                }
            }

            if (!is_dir(_PS_ALL_THEMES_DIR_.$new_theme->directory))
                if (!mkdir(_PS_ALL_THEMES_DIR_.$new_theme->directory))
                    return sprintf($this->l('Error while creating %s directory'), _PS_ALL_THEMES_DIR_.$new_theme->directory);

            $new_theme->add();

            if ($new_theme->id > 0)
            {
                $new_theme->updateMetas($metas_xml);
                $new_theme_array[] = $new_theme;
            }
            else
                $new_theme_array[] = sprintf($this->l('Error while installing theme %s'), $new_theme->name);

        }

        return $new_theme_array;
    }
    
    private function l($s)
    {
        return $s;
    }
    
    /*
     * AdminThemesContoller::isThemeInstalled() duplicated for earlier PS versions. 
     */
    public function isThemeInstalled($theme_name)
    {
        $themes = Theme::getThemes();

        foreach ($themes as $theme_object)
        {
            if ($theme_object->name == $theme_name)
                return true;
        }
        return false;
    }
}